@@ -21,10 +21,10 @@ def main(*args):
         stdout=subprocess.PIPE,
         stderr=subprocess.PIPE
     )
-    stdout, stderr = proc.communicate()
+    _, stderr = proc.communicate()
     if proc.returncode != 0:
         raise FailedToSynchronize(
-            "%s; out: %s; err: %s" % (proc.returncode, stdout, stderr)
+            " ".join(stderr.split('\n')[1:])
         )
     finished = time.time()
 
